==> haskell-crypto-pubkey-types-0.4.3-336-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-3XvLXrfePwjIsbCkiJhvL8
key:                  crypto-pubkey-types-0.4.3-3XvLXrfePwjIsbCkiJhvL8
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  c521c953b47336d261912a3799b76cf4
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-3XvLXrfePwjIsbCkiJhvL8
depends:
    asn1-encoding-0.9.6-IkosapRt3AP5MNPOrKN0lm
    asn1-types-0.3.4-Hyn5kZFolX7gxDa6hTx8x base-4.16.4.0

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-338-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-FODgSNFAve39E65iS9QFGb
key:                  crypto-pubkey-types-0.4.3-FODgSNFAve39E65iS9QFGb
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  a35811a4865f95b9053128a35d815ad3
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-FODgSNFAve39E65iS9QFGb
depends:
    asn1-encoding-0.9.6-6GqwFFmrDK82IsCOUk2PEt
    asn1-types-0.3.4-Jw71wui5Ob54LqM1Y0htWU base-4.16.4.0

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
